Studies on the Facial Feedback Literature
coles2019.RdResults from 138 studies, including 274] effect sizes (Cohen's d), on the facial feedback hypothesis (Coles et al. 2019) .
Usage
data(coles2019)Format
A dataset with 286 rows and 13 variables.
study_id: Unique id for studyes_id: Unique id for effect sizeyi: Effect size in Cohen's dvi: Variance of effect size (SE^2)title: Title of publicationyear: Year of publicationfile_drawer: Publication statusprop_women: Proportion of study that identified as womenvideo_know: Yes: Participants were told they were going to be recorded or the methodology stated that a video camera was placed within participant view. No" Methodology stated that participants were unaware of video recording, that the video camera was hidden, or that there was not a video camerastim: Type of stimuliproc: Type of facial feedback manipulationproc_aware: Whether participants were aware of the facial feedback manipulationw_v_b: Whether the study used a between- or within-subjects design