Studies from ManyBabies 1: Infant-Directed Speech Preference.
manybabies2020.RdMeta-analytic data collected from the ManyBabies Consortium, including 108 effect sizes, aimed at assessing the overall replicability of theoretically-important phenomenon and examing the methodological, situational, cultural, and developmental moderators on infant's preference for infant-directed speech (IDS) over adult-directed speech (ADS)
Usage
data(manybabies2020)Format
A dataset with 108 rows and 8 variables.
lab: name of the lab which observed the effectes_id: unique id for each effect sizeyi: observed effect sizes, expressed as Cohen's dvi: sampling variance (SE^2)ni: sample size for each observed effectage_group: age category for each observed effectmethod: method used for each observed effectnae: whether North American English stimuli were usedage_mo: mean age of babies (in months) for each observed effectage_mo_centered: mean-centered age of babies (in months) for each observed effect