Data collected from meta-analyses on intelligence research
nuijten2020.RdData resulting from 131 meta-analyses, including 2443 effect sizes (fisher-z), on different areas of intelligence research (Nuijten et al. 2020)
Usage
data(nuijten2020)Format
A dataset with 2443 rows and 14 variables.
study_id: Unique id for studyeffect_id: Unique id for effect sizeauthors: identifier for the primary study within a meta-analysis based o the first author of the study or the sample usedyear: year in which the primary study was reportedyi: original effect size converted to a Fishers z valuevi: variance around the z value inyini: total sample size of the primary studyes: effect size as indicated intype_esse: standard errors of the effect sizetype_es: the type of effect size extracted from the meta-analysis; 1 = r transformed to Fishers z, 2 = Hedge's g, 3 = log odds ratio 4 = Cohen's d, 5 = Hazard Ratio, 6, 7, 8 = othertype: type of IQ research summarized by the meta-analysis; 1 = Correlational, 2 = Group_differences 3 = Experiments/Interventions, 4 = Toxicology, 5 = (Behavior) Geneticscitations: number of times the primary study was citedcountrycode: country in which the first author of a primary study was situated at the time of publicationjrnl_impact: impact factor in 2014 of the journal where the primary study was publishedsimilarity: whether the primary study matched the research question of the meta-analysis; 0 = dissimilar, 1 = similar