Studies on the impact of working-memory training on near- and far-transfer measures
sala2019.RdResults from 332 studies, including 1,555 effect sizes (Hedge's g), on whether skills learned from cognitive training generalize to other situations (Sala et al. 2019) .
Usage
data(sala2019)Format
A data frame with 1,555 rows and 10 variables:
* study_id: unique id for each meta-analysis
* es_id: unique id for each effect size
* yi: the observed effect size, expressed in Hedge's g
* vi: the variance of the observed effect size
* ni: the total sample size for the observed effect size in the meta-analysis
* author: author of study
* comparison: type of control group ("Active" or "Non-active")
* age: Age group used in study ("adults", "LD children", "TD children", "old", or "children")
* test: test used in study
* model: indicator for which model the study is used (see paper for details)