Studies on the association between goal orientation and performance adaptation
stasielowicz2019a.RdResults from 35 studies, including 76 effect sizes (r), on learning goal orientation and perfromance adaptation (Stasielowicz 2019) .
Usage
data("stasielowicz2019a")Format
A data frame with 76 rows and 24 variables:
study_id: unique id for studyes_id: unique id for effect sizeauthor: author of studypub_year: publication yearpub_type: publication type (0 = journal article, 2 = book chapter, 3 = dissertation, 4 = master's thesis, 5 = bachelor's thesis, 6 = conference proceedings, 7 = report, 8 = other)peer_review: whethere publication was peer-reviewed (0 = no, 1 = yes)n: sample size of effect sizeyi: effect size (r)vi: sampling variance of effect size (SE^2)adapt_measures: assessment method(s) of adaptation used in the study (1 = self-report, 2 = other people, 3 = objective, 4 = mixed)adapt_method: assessment method of adaption (0 = subjective ratings, 1 = objective scores)adapt_method_specific: specific assessment method of adaptation used for the particular effect size (1 = self-report, 2 = other people, 3 = objective)go_measure: instrument used to assess goal orientationfinanc_support: financial support (0 = no, 1 = yes)age: mean age of sampleage_imputed: mean age of sample (imputed)sex: sex of sample (1 = female sample, 2 = male sample, 3 = mixed sample)perc_men: proportion of men in the samplecountry: country where sampled was collectedsample: sample type (1 = students, 2 = employees, 3 = manager, 4 = mixed, 5 = other)level: level (1 = individuals, 2 = team)complexity_component: component complexity of the task (0 = relatively low, 1 = relatively high)complexity_coordinative: coordinative complexity of the task (0 = relatively low, 1 = relatively high)complexity_dynamic: which complexity aspect changed while completing task (0 = neither component nor coordinative, 1 = only component, 2 = only coordinative, 3 = both component and coordinative)
Details
Further details can be found at https://osf.io/szfwx/