Studies on juvenile recidivism
wibbelink2017.RdResults from 17 studies, including 100 effect sizes (Cohen's D) on the associations between mental health disorders of delinquent juveniles and subsequent delinquent behavior
Usage
data(wibbelink2017)Format
A data frame with 100 rows and 10 variables.
study_id: unique id for each studyes_id: unique id for each effect sizeyi: observed effect sizes (Cohen's d)vi: sampling variance (SE^2)pstatpub: dummy variable encoding whether the study was published, 0 = unpublished, 1 = publishedpstatnotpub: dummy variable encoding whether the study was unpublished, 0 = published, 1 = unpublishedtypgen: dummy variable encoding the type of recidivism behavior 0 = not applicable, 1 = generaltypovert: dummy variable encoding the type of recidivism behavior 0 = not applicable, 1 = overttypcovert: dummy variable encoding the type of recidivism behavior 0 = not applicable, 1 = covertpyear: the publication year of the study; mean-centered