Meta-analytic data collected from the ManyBabies Consortium, including 108 effect sizes, aimed at assessing the overall replicability of theoretically-important phenomenon and examing the methodological, situational, cultural, and developmental moderators on infant's preference for infant-directed speech (IDS) over adult-directed speech (ADS) manybabies2020quantifyingpsymetadata
data(manybabies2020)A dataset with 108 rows and 8 variables.
lab: name of the lab which observed the effect
es_id: unique id for each effect size
yi: observed effect sizes, expressed as Cohen's d
vi: sampling variance (SE^2)
ni: sample size for each observed effect
age_group: age category for each observed effect
method: method used for each observed effect
nae: whether North American English stimuli were used
age_mo: mean age of babies (in months) for each observed effect
age_mo_centered: mean-centered age of babies (in months) for each observed effect