Results from 17 studies, including 100 effect sizes (Cohen's D) on the associations between mental health disorders of delinquent juveniles and subsequent delinquent behavior
data(wibbelink2017)A data frame with 100 rows and 10 variables.
study_id: unique id for each study
es_id: unique id for each effect size
yi: observed effect sizes (Cohen's d)
vi: sampling variance (SE^2)
pstatpub: dummy variable encoding whether the study was published, 0 = unpublished, 1 = published
pstatnotpub: dummy variable encoding whether the study was unpublished, 0 = published, 1 = unpublished
typgen: dummy variable encoding the type of recidivism behavior 0 = not applicable, 1 = general
typovert: dummy variable encoding the type of recidivism behavior 0 = not applicable, 1 = overt
typcovert: dummy variable encoding the type of recidivism behavior 0 = not applicable, 1 = covert
pyear: the publication year of the study; mean-centered
Wibbelink et al. (2017). A meta-analysis of the association between mental health disorders and juvenile recidivism. Aggression and Violent Behavior, 33, 78-90.